#===============================================================================
#. Ttulo   : Anlise quantitativa de dados - AQE - Ajustamento
#. Autor    : Jos Cludio Faria/UESC/DCET
# Data     : 2023-06-15 16:05:52
# Objetivos:
#===============================================================================
# a) Apresentar os recursos bsicos do R para anlise de regresso
# b) Fundamentao em regresso linear simples
# c) Fundamentao em lgebra de matrizes
# d) Fundamentao na funo lm (stats)
#===============================================================================

#. nfase em lgebra de matrizes
#.. +----------------------+
#.. |             -1       |
#.. | b_est = (X'X) . X'Y  |    BLUE: Best Linear Unbiased Estimator
#.. +----------------------+
#... b_est: soluo matricial do mtodo dos mnimos quadrados dos erros.

#===============================================================================
# Operaes matriciais abaixo permitem a obteno das estimativas (b_est)
# dos parmetros dos modelos lineares.
#===============================================================================
x <- c(10, 20, 30, 40, 50, 60, 70)
y <- c(1000, 2300, 3600, 4500, 5400, 5800, 5600)
#y <- c(3000, 2300, 3600, 4500, 5400, 5800, 5600)  # y mais adequado ao modelo linear III grau


#.. Modelos
#-------------------------------------------------------------------------------
 (X <- cbind(1, x))             # linear I grau
 colnames(X) <- c('Int', 'x')
X

# (X <- cbind(x))               # linear I grau: forando origem
# colnames(X) <- c('x')
# X

# (X <- cbind(1, x, x^2))       # linear II grau
# colnames(X) <- c('Int', 'x', 'x^2')
# X


# (X <- cbind(x, x^2))          # linear II grau: forando origem
# colnames(X) <- c('x', 'x^2')
# X

# (X <- cbind(1, x, x^2, x^3))  # linear III grau
# colnames(X) <- c('Int', 'x', 'x^2', 'x^3')
# X
#-------------------------------------------------------------------------------

(Y <- cbind(y))

(XlX     <- t(X) %*% X)      # X'X

                             #     -1
(XlX_inv <- solve(XlX))      # (X'X) 

(XlY     <- t(X) %*% Y)      #  X'Y

                             #      -1     
(b_est   <- XlX_inv %*% XlY) # (X'X) . X'Y

(Y_est   <- X %*% b_est)     # Y: valores estimados pelo modelo ajustado

(res     <- Y - Y_est)       # Erros

# Visualizando os dados
plot(y ~ x,
     xlim=c(0, 70),
     ylim=c(0, 7000),
     pch=19,
     col='darkgreen')

# Sobrepondo os valores estimados pelo modelo ajustado (curva suavizada)
lines(spline(Y_est ~ x,
             n=1e3),
      col='red')

points(Y_est ~ x,
       col='red',
       pch=19)


#. nfase na funo de alto nvel do R - lm (package:stats)
#.. Modelos
#-------------------------------------------------------------------------------
rl <- lm(y ~ x)                     # linear I grau
# rl <- lm(y ~ 0 + x)               # linear II grau: forando origem
# rl <- lm(y ~ x + I(x^2))          # linear II grau
# rl <- lm(y ~ 0 + x + I(x^2))      # linear II grau: forando origem
# rl <- lm(y ~ x + I(x^2) + I(x^3)) # linear III grau
#-------------------------------------------------------------------------------
summary(rl)
class(rl)
mode(rl)                   # r^2 = SQDreg/SQDtot
names(rl)

# Visualizando os dados
plot(y ~ x,
     xlim=c(0, 70),
     ylim=c(0, 7000),
     pch=19,
     col='darkgreen')

# Sobrepondo o modelo ajustado
lines(spline(fitted(rl) ~ x,
             n=1e3),
      col='red')

points(fitted(rl) ~ x,
       col='red',
       pch=19)

#. Verificando apresentao grfica com todos os modelos
plot(y ~ x,
     xlim=c(0, 70),
     ylim=c(0, 7000),
     pch=19,
     col='darkgreen')

# Linear I grau
lines(fitted(lm(y ~ x)) ~ x,
      col='blue')

# Linear I grau: forando origem
lines(fitted(lm(y ~ 0 + x)) ~ x,
      col='blue',
      lty=2)

# Linear II grau
lines(spline(fitted(lm(y ~ x + I(x^2))) ~ x,
             n=1e3),
      col='red',
      lw=2)

# Linear II grau: forando origem
lines(spline(fitted(lm(y ~ 0 + x + I(x^2))) ~ x, 
             n=1e3),
      col='red',
      lw=2,
      lty=2)

# Linear III grau
lines(spline(fitted(lm(y ~ x + I(x^2)+ I(x^3))) ~ x,
             n=1e3),
      col='darkgreen',
      lw=2)

#. Alternativa para estudos
# Modelando novos dados
(x <- seq(1, 10, by=.1))
(y <- 3*x + .5*x^2 + rnorm(length(x)))

library(DescTools)

# Necessrio fazer este data.frame para plotar por este mtodo
dF <- data.frame(x=x,
                 y=y)

# Necessrio informar o data.frame dF na funo lm
r_desc <- lm(y ~ poly(x,
                      degree=2),
             dF)

# Uma lista com muitas informaes!
str(r_desc)

plot(y ~ x,
     xlim=c(0, 10),
     ylim=c(0, 80),
     pch='.',
     cex=3,
     col=gray(.5))

# Ser executado o mtodo "lines.lm" do pacote [DescTools]
lines(r_desc,
      col=hblue,
      pred.level=0.95,
      n=1e3)

#.. Plotando vrios modelos
rm(x)
PlotFun(x ~ x)

PlotFun(x^2 ~ x,
        ylim=c(-20, 20))

PlotFun(x^3 ~ x,
        ylim=c(-20, 20))
