#===============================================================================
#. Ttulo   : Anlise quantitativa de dados - AQE
#. Autor    : Jos Cludio Faria/UESC/DCET
# Data     : 2024-11-27 01:22:59
# Objetivos:
#===============================================================================
# a) Apresentar os recursos bsicos do R para anlise de regresso
# b) Fundamentao em regresso linear
# c) Distino dos modelos lineares dos no lineares
#===============================================================================

#. Verificando se um modelo  ou no linear nos parmetros
pg_1 <- expression(a + b*x)            # polinmio de grau I
pg_2 <- expression(a + b1*x + b2*x^2)  # polinmio de grau II
me   <- expression(a*exp(x/b))          # exponencial - no linear

#.. Observar que as derivadas NO DEPENDEM do parmetro b: Linear -> lm
deriv(pg_1,
      c('a',
        'b'))

#.. Observar que as derivadas NO DEPENDEM dos parmetros b1 e b2: Linear -> lm
deriv(pg_2,
      c('a',
        'b1',
        'b2'))

#.. Observar que as derivadas DEPENDEM do(s) parmetro(s): No linear -> nls
deriv(me,
      c('a',
        'b'))

#.. Informando valores do parmetros e plotando para verificar a forma
#... Informando valores
a  <- 1
b  <- 2
b1 <- 1
b2 <- -0.5
x  <- seq(fr=-10,
          to=10,
          by=.5)

#... Plotando
# polinmio de grau I
plot(eval(pg_1) ~ x,
     type='b')

# polinmio de grau II
plot(eval(pg_2) ~ x,
     type='b')

# exponencial - no linear
plot(eval(me) ~ x,
     type='b')


#. Exemplo bsico de nls
#... alterando o sinal dos parmetros para verificar alterao na forma da curva
plot(eval(expression(-a*exp(x/b))) ~ x,
     type='b')

plot(eval(expression(a*exp(x/-b))) ~ x,
     type='b')

plot(eval(expression(-a*exp(x/-b))) ~ x,
     type='b')


#.. BOD (dataset)
#... Simplest form of fitting a first-order model to these data
str(BOD)
BOD

#... plot
with(BOD,
  plot(demand ~ Time,
       xlim=c(0,8),
       ylim=c(0,20))
)

m_1 <- nls(demand ~ a*(1-exp(-exp(b)*Time)),
           data=BOD,
           start=c(a=20,
                   b=log(.35)),
           trace=TRUE)

summary(m_1)
coef(m_1)
m_1


# Mais fcil
with(BOD,
  points(predict(m_1) ~ Time,
         col='red',
         pch=19)
)

# Mais trabalhoso
#(a <- coef(m_1)[1])
#(b <- coef(m_1)[2])

#with(BOD,
#  points(eval(expression(a*(1-exp(-exp(b)*Time)))) ~ Time,
#    col='red',
#    pch=19)
#)

# Mais fcil
 with(BOD,
  lines(spline(predict(m_1) ~ Time,
               n=1e3),
        col='red',
        lw=2)
)

# Mais trabalhoso
#(a <- coef(m_1)[1])
#(b <- coef(m_1)[2])

#with(BOD,
#  lines(spline(eval(expression(a*(1-exp(-exp(b)*Time)))) ~ Time,
#               n=1e3),
#        col='red',
#        lw=2)
#)

#... Using a self-starting model
fm3 <- nls(demand ~ SSasympOrig(Time, a, b),
           data=BOD,
           trace=TRUE)
summary(fm3)
coef(fm3)
fm3

